-- deep.space v0.03

local lg = love.graphics
local lk = love.keyboard

local level = require "level"
local ui = require "ui"
local timer = require "timer"

local currentShip = love.filesystem.load("maps/perseus")()

function love.load()

	white = {255,255,255}
	lgrey = {200,200,200}
	mgrey = {150,150,150}
	dgrey = {100,100,100}
	black = {0,0,0}
	red = {255,0,0}
	green = {0,255,0}

	love.window.setMode(1280, 760)

	lg.setNewFont("Courier New.ttf", 16)

	thing = "----------------------"

	level.load()
	ui.load()

-- player table

	player = {
		posX = spawnX, 
		posY = spawnY, 
		state = "spawned",
		-- checks if player can move to a square
		check = function(x,y)
			if tiles[currentShip.map[player.posY + y][player.posX + x]].passable then
				if currentShip.objects[player.posY + y][player.posX + x] == 0 then
					return true
				elseif objects[currentShip.objects[player.posY + y][player.posX + x]].passable then
					return true
				else
					return false
				end
			else
				return false
			end
		end,
		-- attempts to move player to a square
		move = function(x,y)
			if player.check(x,y)then
				player.posX = player.posX + x
				player.posY = player.posY + y
				if currentShip.objects[player.posY][player.posX] == 0 then
					player.state = "standing"
				elseif currentShip.objects[player.posY][player.posX] == 2 then
					log.bump("You take the controls...")
					player.state = "pilot"
					player.canMove = "false"
				end				
				return true
			end
			return false
		end,
		-- returns the tileName of a map square in the specified direction
		examine = function(x,y)
			if currentShip.objects[player.posY + y][player.posX + x] ~= 0 then
				return objects[currentShip.objects[player.posY + y][player.posX + x]].name
			else
				return tiles[currentShip.map[player.posY + y][player.posX + x]].name
			end
		end,
		canMove = "true"
	}

menu = {
	state = "false"
}

end

function love.keypressed(key)
	-- player movement
	if player.canMove == "true" then
		if key == "left" then 
			player.move(-1,0)
		end
		
		if key == "right" then 
			player.move(1,0)
		end
		
		if key == "up" then
			player.move(0,-1)
		end
		
		if key == "down" then 
			player.move(0,1)
		end
	end

	if player.state == "pilot" and menu.state == "false" then

		if key == "escape" then
			player.state = "standing"
			player.canMove = "true"
			log.bump("controls...")
			log.bump("You leave the ")
			right.clear(8,11)
		end

	end
	
-- player functions
	if player.state == "standing" and key == "e" then
		log.bump("Examine which direction?")
		player.canMove = "false"
		player.state = "examine"	
	end

	if player.state == "examine" then
		if key == "left" then
			log.bump("You see a " ..player.examine(-1,0).. "...")
			player.state = "standing"
			player.canMove = "true"
		end
		
		if key == "right" then 
			log.bump("You see a " ..player.examine(1,0).. "...")
			player.state = "standing"
			player.canMove = "true"
		end
		
		if key == "up" then 
			log.bump("You see a " ..player.examine(0,-1).. "...")
			player.state = "standing"
			player.canMove = "true"
		end
		
		if key == "down" then 
			log.bump("You see a " ..player.examine(0,1).. "...")
			player.state = "standing"
			player.canMove = "true"
		end

		if key == "escape" then
			log.bump("Never mind...")
			player.state = "standing"
			player.canMove = "true"
		end

	end

-- ship functions
	if player.state == "pilot" then
		if key == "d" then
			log.bump("system diagnostic...")
			log.bump("You run the " ..currentShip.name.. "'s")
			currentShip.state = "diagnostic"
			menu.state = "true"
		elseif key == "i" then
			log.bump("files...")
			log.bump("" ..currentShip.name.. "'s registration")
			log.bump("You look over the ")
			left.clear(1,1)
			left.bump(thing, 1, red)
		end

		if currentShip.state == "diagnostic" and key == "escape" then
			log.bump("the diagnostics...")
			log.bump("You finish looking over ") 
			currentShip.state = "running"
			menu.state = "false"
			right.clear(10,17)
			diag:clear()
		end
	end

end

function love.update(dt)

	level.update(dt)
	ui.update(dt, currentShip)

end

function love.draw()

----------------------- START GAME SCREEN ----------------------- 
	

	lg.push()
	lg.translate(-offsetX, -offsetY)

	level.draw()

	lg.setColor(black)
	lg.rectangle("fill", player.posX * scale, player.posY * scale, scale, scale)
	lg.setColor(white)
	lg.print("@", player.posX * scale, player.posY * scale)

	lg.pop()

------------------------ END GAME SCREEN ------------------------

	ui.draw()


end
