-- ui
ui = {}

local lg = love.graphics

local timer = require "timer"

function ui.load()

	diag = timer.new()

	font = lg.setNewFont("Courier New.ttf", 16)
	wrap = 256 - 16
		
		local l = 32
		local r = lg.getWidth() - 256

left = {
	lines = {},
	bump = function(string, i, c)
		left.lines[i] = lg.newText(font)
		left.lines[i]:addf({c, string}, wrap, "left", l, 32 + (16  * (i-1)))
	end,
	set = function(string, i, c)
		left.lines[i]:setf({c, string}, wrap, "left", r, 32 + (16  * (i-1)))
	end,
	clear = function(x,y)
		for i = x,y do
			left.lines[i]:clear()
		end
	end,
}

right = {
	lines = {},
	bump = function(string, i, c)
		right.lines[i] = lg.newText(font)
		right.lines[i]:addf({c, string}, wrap, "left", r, 32 + (16  * (i-1)))
	end,
	set = function(string, i, c)
		right.lines[i]:setf({c, string}, wrap, "left", r, 32 + (16  * (i-1)))
	end,
	clear = function(x,y)
		for i = x,y do
			right.lines[i]:clear()
		end
	end,
}

log = {
	text1 = "welcome to deep.space...",
	text2 = "",
	text3 = "",
	text4 = "",
	text5 = "",
	text6 = "",
	text7 = "",
	text8 = "",
	text9 = "",
	text10 = "",
	bump = function(string)
		log.text10 = log.text9
		log.text9 = log.text8
		log.text8 = log.text7
		log.text7 = log.text6
		log.text6 = log.text5
		log.text5 = log.text4
		log.text4 = log.text3
		log.text3 = log.text2
		log.text2 = log.text1
		log.text1 = string
	end,
}

end

function ui.update(dt, currentShip)

	diag:update(dt)

-- left ui basic (player info + ui.log)

	left.bump("player information: ", 1, white)
	left.bump(thing, 2, white)
	left.bump("state: " ..player.state.. "", 3, white)
	left.bump("position: " ..player.posX.. ", " ..player.posY.. "", 4, white)
	left.bump("move: " ..player.canMove.. "", 5, white)
	left.bump("menu: " ..menu.state.. "", 6, white)
	left.bump(thing, 7, white)
	left.bump(log.text1, 8, white)
	left.bump(log.text2, 9, lgrey)
	left.bump(log.text3, 10, mgrey)
	left.bump(log.text4, 11, dgrey)
	left.bump(log.text5, 12, dgrey)
	left.bump(log.text6, 13, dgrey)
	left.bump(log.text7, 14, dgrey)
	left.bump(log.text8, 15, dgrey)
	left.bump(log.text9, 16, dgrey)
	left.bump(log.text10, 17, dgrey)
	left.bump(thing, 18, white)

-- right ui basic (ship info + menu)

	right.bump("ship information: ", 1, white)
	right.bump(thing, 2, white)
	right.bump("name: " ..currentShip.name.. "", 3, white)
	right.bump("class: " ..currentShip.class.. "", 4, white)
	right.bump("race: " ..currentShip.race.. "", 5, white)
	right.bump("state: " ..currentShip.state.. "", 6, white)
	right.bump(thing, 7, white)

	if player.state == "pilot" then
		
		right.bump("" ..currentShip.name.. ".terminal", 8, white)
		right.bump(thing, 9, white)
		right.bump("d - " ..currentShip.name.. ".diagnostic", 10, white)
		right.bump("i - " ..currentShip.name.. ".registration", 11, white)
		
		if currentShip.state == "diagnostic" then

			right.clear(10,11)			

			local sys = currentShip.systems

			right.bump("> systems.reactor", 10, white)
			right.bump("", 11, black)
			
			diag:script(function(wait)
				wait(love.math.random(0,1))					
				if sys.reactor.status == "online" then
						right.set("status." ..sys.reactor.status.. "", 11, green)	
				elseif sys.reactor.status == "offline" then
						right.set("status." ..sys.reactor.status.. "", 11, red)
				end
			end)
			
			right.bump("> systems.computer", 12, white)
			right.bump("", 13, black)
					
			if sys.computer.status == "online" then
				diag:script(function(wait)
					wait(love.math.random(0,1))
					right.set("status." ..sys.computer.status.. "", 13, green)
				end)
			elseif sys.computer.status == "offline" then
				diag:script(function(wait)
					wait(love.math.random(0,1))
					right.set("status." ..sys.computer.status.. "", 13, red)
				end)
			end

			right.bump("> systems.engines", 14, white)
			right.bump("", 15, black)
					
			if sys.engines.status == "online" then
				diag:script(function(wait)
					wait(love.math.random(0,1))
					right.set("status." ..sys.engines.status.. "", 15, green)
				end)
			elseif sys.engines.status == "offline" then
				diag:script(function(wait)
					wait(love.math.random(0,1))
					right.set("status." ..sys.engines.status.. "", 15, red)
				end)
			end

			right.bump("> systems.shield", 16, white)
			right.bump("", 17, black)
					
			if sys.shield.status == "online" then
				diag:script(function(wait)
					wait(love.math.random(0,1))
					right.set("status." ..sys.shield.status.. "", 17, green)
				end)
			elseif sys.shield.status == "offline" then
				diag:script(function(wait)
					wait(love.math.random(0,1))
					right.set("status." ..sys.shield.status.. "", 17, red)
				end)
			end
	
		end

	end

end

function ui.draw()

---- left ui bar (player)

	for i = 1, #left.lines do
		lg.draw(left.lines[i])
	end

---- right ui bar (ship)

	for i = 1, #right.lines do
		lg.draw(right.lines[i])
	end

end

return ui